@@ -14,6 +14,7 @@ describe 'trove::db' do
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
     end
 
@@ -25,6 +26,7 @@ describe 'trove::db' do
           :database_max_pool_size  => '21',
           :database_max_retries    => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
           :database_retry_interval => '11', }
       end
 
@@ -36,6 +38,7 @@ describe 'trove::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
     end
 
